package com.hw.mes.service;

import com.hw.mes.api.domain.MesBaseStationInfo;

import java.util.List;

/**
 * 工位信息Service接口
 *
 * @author Yinq
 * @date 2024-01-26
 */
public interface IMesBaseStationInfoService
{
    /**
     * 查询工位信息
     *
     * @param stationId 工位信息主键
     * @return 工位信息
     */
    public MesBaseStationInfo selectMesBaseStationInfoByStationId(Long stationId);

    /**
     * 查询工位信息列表
     *
     * @param mesBaseStationInfo 工位信息
     * @return 工位信息集合
     */
    public List<MesBaseStationInfo> selectMesBaseStationInfoList(MesBaseStationInfo mesBaseStationInfo);

    /**
     * 新增工位信息
     *
     * @param mesBaseStationInfo 工位信息
     * @return 结果
     */
    public int insertMesBaseStationInfo(MesBaseStationInfo mesBaseStationInfo);

    /**
     * 修改工位信息
     *
     * @param mesBaseStationInfo 工位信息
     * @return 结果
     */
    public int updateMesBaseStationInfo(MesBaseStationInfo mesBaseStationInfo);

    /**
     * 批量删除工位信息
     *
     * @param stationIds 需要删除的工位信息主键集合
     * @return 结果
     */
    public int deleteMesBaseStationInfoByStationIds(Long[] stationIds);

    /**
     * 删除工位信息信息
     *
     * @param stationId 工位信息主键
     * @return 结果
     */
    public int deleteMesBaseStationInfoByStationId(Long stationId);
}
